# 浏览量更新接口说明

## 前端实现说明

前端已经在各个详情页面（法律规定、典型案例、表单下载）中添加了浏览量更新功能。当用户访问详情页面时，会向后端发送更新浏览量的请求。

## 接口规范

### 接口地址
```
GET /hasfj/hasfjpages/updateViewCount
```

### 请求参数
| 参数名 | 类型 | 必填 | 说明 |
|-------|------|------|------|
| pageType | string | 是 | 页面类型，可选值: law(法律规定)、case(典型案例)、form(表单下载) |
| formatId | string | 是 | 页面的唯一标识 |

### 返回结果
```json
{
  "code": 200,
  "msg": "操作成功",
  "data": null
}
```

## 后端实现参考

参考现有的 `HtmlPagesController` 或 `HtmlPageApiController` 类，添加一个新的接口方法：

```java
/**
 * 更新页面浏览量
 */
@Operation(summary = "更新页面浏览量")
@GetMapping("/updateViewCount")
public AjaxResult updateViewCount(
    @RequestParam(value = "pageType", required = true) String pageType,
    @RequestParam(value = "formatId", required = true) String formatId) {
    
    HtmlPages htmlPages = new HtmlPages();
    htmlPages.setPageType(pageType);
    htmlPages.setFormatId(formatId);
    htmlPages.setStatus(1); // 只查询启用状态的
    
    List<HtmlPages> list = htmlPagesService.selectHtmlPagesList(htmlPages);
    if (list != null && !list.isEmpty()) {
        HtmlPages page = list.get(0);
        // 更新浏览次数
        page.setViewCount(page.getViewCount() == null ? 1L : page.getViewCount() + 1);
        htmlPagesService.updateHtmlPages(page);
        
        return AjaxResult.success();
    }
    
    return AjaxResult.error("未找到相关页面");
}
```

## 注意事项

1. 为避免重复计数，可考虑添加访问IP或用户会话记录，短时间内重复访问同一页面不增加浏览量
2. 为提高性能，可考虑使用缓存或消息队列，定时批量更新浏览量数据
3. 接口应做好安全防护，防止恶意刷新增加浏览量

## 法律规定列表页错误临时解决方案

### 问题描述

访问法律规定列表页(/hasfjlaw)时出现错误：
```
{"msg":"No static resource hasfi/law_list.","code":500}
```

这是因为后端路由与前端路由冲突导致的。后端试图查找模板 `hasfi/law_list`（拼写错误，应为`hasfj/law_list`）。

### 解决方案

1. 已在Vite配置中添加中间件，使前端优先处理这些路由：
   - /hasfjlaw
   - /hasfjcase
   - /hasfjform
   - /qrcodes

2. 如果中间件方案不起作用，还可以尝试：
   - 修改前端路由为唯一路径，如`/frontend/hasfjlaw`
   - 使用Hash模式路由`/#/hasfjlaw`代替History模式
   - 联系后端开发人员，修复拼写错误（`hasfi/law_list` → `hasfj/law_list`）

### 快速验证方法

为验证路由是否正常工作，可以直接在浏览器地址栏输入以下地址：
```
http://192.168.0.58/#/hasfjlaw
```

这将绕过后端路由，直接访问前端路由。 