import request from '@/utils/request'

// 查询司法局法律规定、典型案例、单下载列表
export function listHasfjpages(query) {
  return request({
    url: '/hasfj/hasfjpages/list',
    method: 'get',
    params: query
  }).catch(error => {
    console.error('获取列表失败:', error);
    throw error;
  })
}

// 查询司法局法律规定、典型案例、单下载详细
export function getHasfjpages(id) {
  return request({
    url: '/hasfj/hasfjpages/' + id,
    method: 'get'
  }).catch(error => {
    console.error('获取详情失败:', error);
    throw error;
  })
}

// 根据访问ID获取页面详情
export function getHasfjpagesByFormatId(formatId) {
  return request({
    url: '/hasfj/hasfjpages/format/' + formatId,
    method: 'get'
  }).catch(error => {
    console.error('根据formatId获取详情失败:', error);
    throw error;
  })
}

// 查询指定类型的页面列表
export function listHasfjpagesByType(pageType) {
  return request({
    url: '/hasfj/hasfjpages/listByType/' + pageType,
    method: 'get'
  }).catch(error => {
    console.error('获取类型列表失败:', error);
    throw error;
  })
}

// 新增司法局法律规定、典型案例、单下载
export function addHasfjpages(data) {
  // 确保数据有效性
  if (data.multiAttachments && typeof data.multiAttachments === 'string') {
    try {
      // 验证是否为有效的JSON
      JSON.parse(data.multiAttachments);
    } catch (e) {
      console.error('添加前验证附件数据格式错误:', e);
      data.multiAttachments = null;
    }
  }
  
  return request({
    url: '/hasfj/hasfjpages',
    method: 'post',
    data: data
  }).catch(error => {
    console.error('添加数据失败:', error);
    throw error;
  })
}

// 修改司法局法律规定、典型案例、单下载
export function updateHasfjpages(data) {
  // 确保数据有效性
  if (data.multiAttachments && typeof data.multiAttachments === 'string') {
    try {
      // 验证是否为有效的JSON
      JSON.parse(data.multiAttachments);
    } catch (e) {
      console.error('更新前验证附件数据格式错误:', e);
      data.multiAttachments = null;
    }
  }
  
  return request({
    url: '/hasfj/hasfjpages',
    method: 'put',
    data: data
  }).catch(error => {
    console.error('更新数据失败:', error);
    throw error;
  })
}

// 删除司法局法律规定、典型案例、单下载
export function delHasfjpages(ids) {
  // 确保IDs格式正确
  // 判断是否为数组，如果是数组则转为逗号分隔的字符串
  let idParam = ids;
  if (Array.isArray(ids)) {
    idParam = ids.join(',');
  } else if (ids !== undefined && ids !== null) {
    // 如果不是数组，确保转为字符串
    idParam = ids.toString();
  }
  
  return request({
    url: '/hasfj/hasfjpages/' + idParam,
    method: 'delete'
  }).catch(error => {
    console.error('删除数据失败:', error);
    // 提供更详细的错误信息
    if (error.response && error.response.status) {
      switch (error.response.status) {
        case 400:
          throw new Error('请求参数错误，请检查删除的ID格式');
        case 401:
          throw new Error('您没有权限执行此操作');
        case 403:
          throw new Error('访问被拒绝，权限不足');
        case 404:
          throw new Error('要删除的记录不存在');
        case 500:
          throw new Error('服务器内部错误，请联系管理员');
        default:
          throw new Error('删除失败: ' + (error.message || '未知错误'));
      }
    }
    throw error;
  });
}

// 删除附件
export function deleteAttachment(attachmentUrl) {
  return request({
    url: '/hasfj/hasfjpages/deleteAttachment',
    method: 'post',
    data: { attachmentUrl }
  }).catch(error => {
    console.error('删除附件失败:', error);
    throw error;
  });
}

// 导入数据
export function importData(data) {
  return request({
    url: '/hasfj/hasfjpages/importData',
    method: 'post',
    data: data,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  }).catch(error => {
    console.error('导入数据失败:', error);
    throw error;
  });
}
