import request from '@/utils/request'

// 登录方法
export function login(username, password, code, uuid) {
  console.log('调用登录API，参数:', { username, code, uuid })
  const data = {
    username,
    password,
    code,
    uuid
  }
  return request({
    url: '/login',
    headers: {
      isToken: false,
      'Content-Type': 'application/json;charset=utf-8'
    },
    method: 'post',
    data: data,
    timeout: 30000
  })
}

// 注册方法
export function register(data) {
  console.log('调用注册API，参数:', data)
  return request({
    url: '/register',
    headers: {
      isToken: false
    },
    method: 'post',
    data: data
  })
}

// 获取用户详细信息
export function getInfo() {
  console.log('获取用户信息')
  return request({
    url: '/getInfo',
    method: 'get'
  })
}

// 退出方法
export function logout() {
  console.log('调用登出API')
  return request({
    url: '/logout',
    method: 'post'
  })
}

// 获取验证码
export function getCodeImg() {
  console.log('获取验证码图片')
  return new Promise((resolve, reject) => {
    request({
      url: '/captchaImage',
      headers: {
        isToken: false,
        'Content-Type': 'application/json;charset=utf-8'
      },
      method: 'get',
      timeout: 30000
    }).then(res => {
      resolve(res)
    }).catch(error => {
      console.error('验证码获取失败:', error)
      resolve({ captchaEnabled: false })
    })
  })
}

export function sendEmailCode(data) {
  return request({
    url: '/auth/mail/send/register',
    headers: {
      isToken: false
    },
    method: 'post',
    timeout: 20000,
    data
  })
}

export function verifyEmailCode(data) {
  return request({
    url: '/auth/mail/verify/register',
    headers: {
      isToken: false
    },
    method: 'post',
    timeout: 20000,
    data
  })
}

export function sendPhoneCode(data) {
  return request({
    url: '/auth/dySms/send/register',
    headers: {
      isToken: false
    },
    method: 'post',
    timeout: 20000,
    data
  })
}

export function verifyPhoneCode(data) {
  return request({
    url: '/auth/dySms/verify/register',
    headers: {
      isToken: false
    },
    method: 'post',
    timeout: 20000,
    data
  })
}