import { createApp } from 'vue'

import Cookies from 'js-cookie'

import ElementPlus from 'element-plus'
import locale from 'element-plus/dist/locale/zh-cn.mjs'// 中文语言
import 'element-plus/dist/index.css'

import '@/assets/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'
import directive from './directive' // directive


// 注册指令
import plugins from './plugins' // plugins
import { download } from '@/utils/request'

// svg图标
import 'virtual:svg-icons-register'
import SvgIcon from '@/components/SvgIcon'
import elementIcons from '@/components/SvgIcon/svgicon'

import './permission' // permission control

import { useDict } from '@/utils/dict'
import { parseTime, resetForm, addDateRange, handleTree, selectDictLabel, selectDictLabels } from '@/utils/boyue'

// 分页组件
import Pagination from '@/components/Pagination'
// 自定义表格工具组件
import RightToolbar from '@/components/RightToolbar'
// 文件上传组件
import FileUpload from "@/components/FileUpload"
// 图片上传组件
import ImageUpload from "@/components/ImageUpload"
// 图片预览组件
import ImagePreview from "@/components/ImagePreview"
// 自定义树选择组件
import TreeSelect from '@/components/TreeSelect'
// 字典标签组件
import DictTag from '@/components/DictTag'
// 富文本编辑器组件
import Editor from "@/components/Editor";
// Qrcode 二维码组件
import QRCodeView from "@/components/QRCodeView";
// JsBarcode 条形码组件
import JsBarcodeView from "@/components/JsBarcodeView";

const app = createApp(App)

// 全局方法挂载
app.config.globalProperties.useDict = useDict
app.config.globalProperties.download = download
app.config.globalProperties.parseTime = parseTime
app.config.globalProperties.resetForm = resetForm
app.config.globalProperties.handleTree = handleTree
app.config.globalProperties.addDateRange = addDateRange
app.config.globalProperties.selectDictLabel = selectDictLabel
app.config.globalProperties.selectDictLabels = selectDictLabels

// 全局组件挂载
app.component('DictTag', DictTag)
app.component('Pagination', Pagination)
app.component('TreeSelect', TreeSelect)
app.component('FileUpload', FileUpload)
app.component('ImageUpload', ImageUpload)
app.component('ImagePreview', ImagePreview)
app.component('RightToolbar', RightToolbar)
app.component('Editor', Editor)
app.component('QRCodeView', QRCodeView)
app.component('JsBarcodeView', JsBarcodeView)

app.use(router)
app.use(store)
app.use(plugins)
app.use(elementIcons)
app.component('svg-icon', SvgIcon)

directive(app)

// 使用element-plus 并且设置全局的大小
app.use(ElementPlus, {
  locale: locale,
  // 支持 large、default、small
  size: localStorage.getItem('size') || 'default'
})

// 添加全局错误处理
app.config.errorHandler = (err, vm, info) => {
  console.error('Vue错误:', err);
  console.error('错误信息:', info);
}

// 注释掉VForm相关代码，因为在浏览器环境中不支持require
// import '@/../lib/vform/designer.style.css'  //引入VForm3样式
// 
// // 定义加载VForm的函数
// const loadVForm = (retryCount = 0, maxRetries = 3) => {
//   console.log(`尝试加载VForm (${retryCount + 1}/${maxRetries + 1})`)
//   try {
//     // 使用ES模块方式导入VForm
//     import('@/../lib/vform/designer.umd.js')
//       .then(module => {
//         console.log('VForm加载成功:', module)
//         const VForm3 = module.default || module
//         if (VForm3) {
//           app.use(VForm3)
//           console.log('VForm注册成功')
//         } else {
//           console.error('VForm加载失败: 模块为空')
//           retryIfNeeded()
//         }
//       })
//       .catch(error => {
//         console.error('VForm加载错误:', error)
//         retryIfNeeded()
//       })
//     
//     function retryIfNeeded() {
//       if (retryCount < maxRetries) {
//         console.log(`将在1秒后重试加载VForm (${retryCount + 2}/${maxRetries + 1})`)
//         setTimeout(() => loadVForm(retryCount + 1, maxRetries), 1000)
//       } else {
//         console.error(`VForm加载失败，已达到最大重试次数(${maxRetries + 1})`)
//         // 导入ElMessage
//         import('element-plus').then(({ ElMessage }) => {
//           ElMessage.error('系统资源加载失败，请刷新页面重试')
//         })
//       }
//     }
//   } catch (error) {
//     console.error('VForm加载主函数错误:', error)
//   }
// }
// 
// // 尝试加载VForm
// loadVForm()

import modelerStore from '@/components/Process/common/global'
app.config.globalProperties.modelerStore = modelerStore

app.mount('#app')

// 添加初始化超时检测
const MAX_INIT_TIME = 30000; // 30秒
let initTimeout = setTimeout(() => {
  // 检查页面是否已经初始化完成
  const appElement = document.getElementById('app');
  if (appElement && appElement.childElementCount > 0) {
    // 页面已经有内容，清除超时
    clearTimeout(initTimeout);
  } else {
    // 页面仍在加载中，显示错误提示
    console.error('页面初始化超时，可能存在资源加载问题');

    // 创建错误提示元素
    const errorDiv = document.createElement('div');
    errorDiv.style.position = 'fixed';
    errorDiv.style.top = '50%';
    errorDiv.style.left = '50%';
    errorDiv.style.transform = 'translate(-50%, -50%)';
    errorDiv.style.padding = '20px';
    errorDiv.style.backgroundColor = '#f56c6c';
    errorDiv.style.color = 'white';
    errorDiv.style.borderRadius = '4px';
    errorDiv.style.zIndex = '9999';
    errorDiv.innerHTML = `
      <h3>系统加载失败</h3>
      <p>可能原因：</p>
      <ul>
        <li>网络连接问题</li>
        <li>服务器未响应</li>
        <li>资源加载失败</li>
      </ul>
      <button onclick="location.reload()" style="padding: 8px 16px; background: white; color: #f56c6c; border: none; border-radius: 4px; cursor: pointer;">刷新页面</button>
    `;

    document.body.appendChild(errorDiv);
  }
}, MAX_INIT_TIME);
