import Cookies from 'js-cookie'

const TokenKey = 'Admin-Token'

// 检查当前环境
const isProd = import.meta.env.MODE === 'production'
console.log('当前环境:', import.meta.env.MODE, '是否生产环境:', isProd)

// 在生产环境中使用Cookies存储Token，开发环境使用localStorage
export function getToken() {
  if (isProd) {
    // 生产环境使用Cookies
    const token = Cookies.get(TokenKey)
    console.log('从Cookies获取Token:', token)
    return token
  } else {
    // 开发环境使用localStorage
    const token = localStorage.getItem(TokenKey)
    console.log('从localStorage获取Token:', token)
    return token
  }
}

export function setToken(token: string) {
  if (isProd) {
    // 生产环境使用Cookies，设置路径为根路径，确保所有页面可访问
    console.log('将Token保存到Cookies:', token)
    return Cookies.set(TokenKey, token, { path: '/' })
  } else {
    // 开发环境使用localStorage
    console.log('将Token保存到localStorage:', token)
    return localStorage.setItem(TokenKey, token)
  }
}

export function removeToken() {
  if (isProd) {
    // 生产环境使用Cookies
    console.log('从Cookies移除Token')
    return Cookies.remove(TokenKey, { path: '/' })
  } else {
    // 开发环境使用localStorage
    console.log('从localStorage移除Token')
    return localStorage.removeItem(TokenKey)
  }
}
